pub struct AuditGenerationConfig {
pub enabled: bool,
pub generate_workpapers: bool,
pub engagement_types: AuditEngagementTypesConfig,
pub workpapers: WorkpaperConfig,
pub team: AuditTeamConfig,
pub review: ReviewWorkflowConfig,
}Expand description
Audit engagement and workpaper generation configuration.
Fields
enabled: boolEnable audit engagement generation
generate_workpapers: bool[Not yet wired] Generate workpaper data — reserved for future fine-grained control.
Currently, workpapers are always generated when enabled = true.
engagement_types: AuditEngagementTypesConfig[Not yet wired] Default engagement type distribution — reserved for future fine-grained control. Currently, engagement types are determined by the audit generator’s internal defaults.
workpapers: WorkpaperConfig[Not yet wired] Workpaper configuration — reserved for future fine-grained control. Currently, workpaper settings are determined by the audit generator’s internal defaults.
team: AuditTeamConfig[Not yet wired] Team configuration — reserved for future fine-grained control. Currently, team composition is determined by the audit generator’s internal defaults.
review: ReviewWorkflowConfig[Not yet wired] Review workflow configuration — reserved for future fine-grained control. Currently, review workflow is determined by the audit generator’s internal defaults.